==> schooltool_0.9.orig.tar.gz: schooltool-0.9/Zope3/src/zope/app/event/interfaces.py <==
##############################################################################
#
# Copyright (c) 2002, 2003 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Event-related interfaces

$Id: interfaces.py 26736 2004-07-23 22:08:09Z pruggera $
"""
__docformat__ = 'restructuredtext'

from zope.interface import Interface, Attribute

class IObjectEvent(Interface):
    """Something has happened to an object.

    The object that generated this event is not necessarily the object
    refered to by location.
    """

    object = Attribute("The subject of the event.")

class IObjectCreatedEvent(IObjectEvent):
    """An object has been created.

    The location will usually be ``None`` for this event."""

class IObjectCopiedEvent(IObjectCreatedEvent):
    """An object has been copied"""

class IObjectModifiedEvent(IObjectEvent):
    """An object has been modified"""

class IObjectAnnotationsModifiedEvent(IObjectModifiedEvent):
    """An object's annotations have been modified"""

class IObjectContentModifiedEvent(IObjectModifiedEvent):
    """An object's content has been modified"""

==> schooltool_0.11.2.orig.tar.gz: schooltool-0.11.2/Zope3/src/zope/app/event/interfaces.py <==
##############################################################################
#
# Copyright (c) 2002, 2003 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
"""Event-related interfaces

$Id: interfaces.py 30703 2005-06-09 11:56:59Z oestermeier $
"""
__docformat__ = 'restructuredtext'

from zope.interface import Interface, Attribute


class IObjectEvent(Interface):
    """Something has happened to an object.

    The object that generated this event is not necessarily the object
    refered to by location.
    """

    object = Attribute("The subject of the event.")

class IObjectCreatedEvent(IObjectEvent):
    """An object has been created.

    The location will usually be ``None`` for this event."""

class IObjectCopiedEvent(IObjectCreatedEvent):
    """An object has been copied"""

class IObjectModifiedEvent(IObjectEvent):
    """An object has been modified"""

class IModificationDescription(Interface) :
    """ Marker interface for descriptions of object modifications.
    
    Can be used as a parameter of an IObjectModifiedEvent."""

class IAttributes(IModificationDescription) :
    """ Describes the attributes of an interface.
   
    """
    
    interface = Attribute("The involved interface.")
    attributes = Attribute("A sequence of modified attributes.")
    
    
# BBB: will go in Zope3.3

class IObjectAnnotationsModifiedEvent(IObjectModifiedEvent):
    """An object's annotations have been modified"""

class IObjectContentModifiedEvent(IObjectModifiedEvent):
    """An object's content has been modified"""
